@@ -1,9 +1,6 @@
 // Copyright 2019-2024 Tauri Programme within The Commons Conservancy
 // SPDX-License-Identifier: Apache-2.0
 // SPDX-License-Identifier: MIT
-
-use std::ops::Deref;
-
 use serde::{Deserialize, Deserializer};
 use serde_json::Value as JsonValue;
 use tauri_runtime::window::is_label_valid;
@@ -12,33 +9,8 @@ use crate::plugin::{Builder, TauriPlugin};
 use crate::{command, ipc::CallbackFn, EventId, Result, Runtime};
 use crate::{AppHandle, Emitter, Webview};
 
-use super::{is_event_name_valid, EventTarget};
-
-pub struct EventName(String);
-
-impl Deref for EventName {
-  type Target = str;
-
-  fn deref(&self) -> &Self::Target {
-    &self.0
-  }
-}
-
-impl<'de> Deserialize<'de> for EventName {
-  fn deserialize<D>(deserializer: D) -> std::result::Result<Self, D::Error>
-  where
-    D: Deserializer<'de>,
-  {
-    let event_id = String::deserialize(deserializer)?;
-    if is_event_name_valid(&event_id) {
-      Ok(EventName(event_id))
-    } else {
-      Err(serde::de::Error::custom(
-        "Event name must include only alphanumeric characters, `-`, `/`, `:` and `_`.",
-      ))
-    }
-  }
-}
+use super::EventName;
+use super::EventTarget;
 
 pub struct WebviewLabel(String);
 
@@ -65,41 +37,41 @@ impl<'de> Deserialize<'de> for WebviewLabel {
 }
 
 #[command(root = "crate")]
-pub async fn listen<R: Runtime>(
+async fn listen<R: Runtime>(
   webview: Webview<R>,
   event: EventName,
   target: EventTarget,
   handler: CallbackFn,
 ) -> Result<EventId> {
-  webview.listen_js(&event, target, handler)
+  webview.listen_js(event.as_str_event(), target, handler)
 }
 
 #[command(root = "crate")]
-pub async fn unlisten<R: Runtime>(
+async fn unlisten<R: Runtime>(
   webview: Webview<R>,
   event: EventName,
   event_id: EventId,
 ) -> Result<()> {
-  webview.unlisten_js(&event, event_id)
+  webview.unlisten_js(event.as_str_event(), event_id)
 }
 
 #[command(root = "crate")]
-pub async fn emit<R: Runtime>(
+async fn emit<R: Runtime>(
   app: AppHandle<R>,
   event: EventName,
   payload: Option<JsonValue>,
 ) -> Result<()> {
-  app.emit(&event, payload)
+  app.emit(event.as_str(), payload)
 }
 
 #[command(root = "crate")]
-pub async fn emit_to<R: Runtime>(
+async fn emit_to<R: Runtime>(
   app: AppHandle<R>,
   target: EventTarget,
   event: EventName,
   payload: Option<JsonValue>,
 ) -> Result<()> {
-  app.emit_to(target, &event, payload)
+  app.emit_to(target, event.as_str(), payload)
 }
 
 /// Initializes the event plugin.
